@@ -192,6 +192,22 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
     
     
      class(loadings) <- "loadings"
+     #Find the summary statistics of Variance accounted for
+     #normally just found in the print function  (added 4/22/17)
+     #from  the print function
+      if(is.null(Phi)) {if(nfactors > 1)  {vx <- colSums(loadings^2) } else {vx <- sum(loadings^2)
+    }} else {vx <- diag(Phi %*% t(loadings) %*% loadings)
+      	 }
+          
+     	vtotal <- sum(communalities + uniquenesses)
+             names(vx) <- colnames(loadings)
+          varex <- rbind("SS loadings" =   vx)
+          varex <- rbind(varex, "Proportion Var" =  vx/vtotal)
+         if (nfactors > 1) {
+                      varex <- rbind(varex, "Cumulative Var"=  cumsum(vx/vtotal))
+                       varex <- rbind(varex, "Proportion Explained"=  vx/sum(vx))
+                      varex <- rbind(varex, "Cumulative Proportion"=  cumsum(vx/sum(vx))) 
+                      }
      
     result$n.obs <- n.obs
     stats <- factor.stats(r,loadings,Phi,n.obs,fm="pc")
@@ -222,6 +238,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
     result$weights <-  stats$weights
     result$r.scores <-  stats$r.scores
      result$rot.mat <- rot.mat
+     result$Vaccounted <-varex
     if(!is.null(Phi) && oblique.scores) {
                        result$Structure <- loadings %*% Phi} else {result$Structure <- loadings
                        }
