@@ -1,181 +1,13 @@
 ### R code from vignette source 'overview.Rnw'
 
 ###################################################
-### code chunk number 1: overview.Rnw:427-430
-###################################################
-library(psych)
-data(sat.act) 
-describe(sat.act)  #basic descriptive statistics
-
-
-###################################################
-### code chunk number 2: overview.Rnw:437-439
-###################################################
- #basic descriptive statistics by a grouping variable.
-describeBy(sat.act,sat.act$gender,skew=FALSE,ranges=FALSE)
-
-
-###################################################
-### code chunk number 3: overview.Rnw:447-450
-###################################################
-sa.mat <- describeBy(sat.act,list(sat.act$gender,sat.act$education),
- skew=FALSE,ranges=FALSE,mat=TRUE)
-headTail(sa.mat)
-
-
-###################################################
-### code chunk number 4: outlier
-###################################################
-png( 'outlier.png' )
-d2 <- outlier(sat.act,cex=.8)
-dev.off()
-
-
-###################################################
-### code chunk number 5: overview.Rnw:481-485
-###################################################
-x <- matrix(1:120,ncol=10,byrow=TRUE)
-colnames(x) <- paste('V',1:10,sep='')
-new.x <- scrub(x,3:5,min=c(30,40,50),max=70,isvalue=45,newvalue=NA)
-new.x
-
-
-###################################################
-### code chunk number 6: pairspanels
-###################################################
-png( 'pairspanels.png' )
-sat.d2 <- data.frame(sat.act,d2) #combine the d2 statistics from before with the sat.act data.frame
-pairs.panels(sat.d2,bg=c("yellow","blue")[(d2 > 25)+1],pch=21)
-dev.off()
-
-
-###################################################
-### code chunk number 7: affect
-###################################################
-png('affect.png')
-pairs.panels(affect[14:17],bg=c("red","black","white","blue")[affect$Film],pch=21,
-     main="Affect varies by movies ")
-dev.off()
-
-
-###################################################
-### code chunk number 8: overview.Rnw:545-547
-###################################################
-data(sat.act)
-violinBy(sat.act[5:6],sat.act$gender,grp.name=c("M", "F"),main="Density Plot by gender for SAT V and Q")
-
-
-###################################################
-### code chunk number 9: overview.Rnw:562-563
-###################################################
-lowerCor(sat.act)
-
-
-###################################################
-### code chunk number 10: overview.Rnw:570-576
-###################################################
-female <- subset(sat.act,sat.act$gender==2)
- male <- subset(sat.act,sat.act$gender==1)
-lower <- lowerCor(male[-1])
-upper <- lowerCor(female[-1])
-both <- lowerUpper(lower,upper)
-round(both,2)
-
-
-###################################################
-### code chunk number 11: overview.Rnw:582-584
-###################################################
-diffs <-  lowerUpper(lower,upper,diff=TRUE)
-round(diffs,2)
-
-
-###################################################
-### code chunk number 12: corplot.png
-###################################################
-png('corplot.png')
-corPlot(Thurstone,numbers=TRUE,upper=FALSE,diag=FALSE,main="9 cognitive variables from Thurstone")
-dev.off()
-
-
-###################################################
-### code chunk number 13: circplot.png
-###################################################
-png('circplot.png')
-circ <- sim.circ(24)
-r.circ <- cor(circ)
-corPlot(r.circ,main='24 variables in a circumplex')
-dev.off()
-
-
-###################################################
-### code chunk number 14: overview.Rnw:632-633
-###################################################
-corr.test(sat.act)
-
-
-###################################################
-### code chunk number 15: overview.Rnw:644-645
-###################################################
-r.test(50,.3)
-
-
-###################################################
-### code chunk number 16: overview.Rnw:651-652
-###################################################
-r.test(30,.4,.6)
-
-
-###################################################
-### code chunk number 17: overview.Rnw:659-660
-###################################################
-r.test(103,.4,.5,.1)
-
-
-###################################################
-### code chunk number 18: overview.Rnw:666-667
-###################################################
-r.test(103,.5,.6,.7,.5,.5,.8)  #steiger Case B 
-
-
-###################################################
-### code chunk number 19: overview.Rnw:675-676
-###################################################
-cortest(sat.act)
-
-
-###################################################
-### code chunk number 20: overview.Rnw:687-688
-###################################################
-draw.tetra()
-
-
-###################################################
-### code chunk number 21: overview.Rnw:699-700
-###################################################
-draw.cor(expand=20,cuts=c(0,0))
-
-
-###################################################
-### code chunk number 22: overview.Rnw:720-721
-###################################################
-setCor(y = 5:9,x=1:4,data=Thurstone)
-
-
-###################################################
-### code chunk number 23: overview.Rnw:728-730
-###################################################
-sc <- setCor(y = 5:9,x=3:4,data=Thurstone,z=1:2)
-round(sc$residual,2)
-
-
-###################################################
-### code chunk number 24: overview.Rnw:797-798
+### code chunk number 1: overview.Rnw:430-431
 ###################################################
 if(!require('GPArotation')) {stop('GPArotation must be installed to do rotations')} 
 
 
 ###################################################
-### code chunk number 25: overview.Rnw:806-809
+### code chunk number 2: overview.Rnw:439-442
 ###################################################
 if(!require('GPArotation')) {stop('GPArotation must be installed to do rotations')} else {
 f3t <- fa(Thurstone,3,n.obs=213)
@@ -183,7 +15,7 @@ f3t }
 
 
 ###################################################
-### code chunk number 26: overview.Rnw:830-834
+### code chunk number 3: overview.Rnw:463-467
 ###################################################
 if(!require('GPArotation')) {stop('GPArotation must be installed to do rotations')} else {
 f3 <- fa(Thurstone,3,n.obs = 213,fm="pa")
@@ -192,130 +24,130 @@ f3o}
 
 
 ###################################################
-### code chunk number 27: overview.Rnw:855-857
+### code chunk number 4: overview.Rnw:488-490
 ###################################################
 f3w <- fa(Thurstone,3,n.obs = 213,fm="wls")
 print(f3w,cut=0,digits=3)
 
 
 ###################################################
-### code chunk number 28: overview.Rnw:869-870
+### code chunk number 5: overview.Rnw:502-503
 ###################################################
 plot(f3t)
 
 
 ###################################################
-### code chunk number 29: overview.Rnw:882-883
+### code chunk number 6: overview.Rnw:515-516
 ###################################################
 fa.diagram(f3t)
 
 
 ###################################################
-### code chunk number 30: overview.Rnw:902-904
+### code chunk number 7: overview.Rnw:535-537
 ###################################################
 p3p <-principal(Thurstone,3,n.obs = 213,rotate="Promax")
 p3p
 
 
 ###################################################
-### code chunk number 31: overview.Rnw:923-925
+### code chunk number 8: overview.Rnw:556-558
 ###################################################
 om.h <- omega(Thurstone,n.obs=213,sl=FALSE)
 op <- par(mfrow=c(1,1))
 
 
 ###################################################
-### code chunk number 32: overview.Rnw:936-937
+### code chunk number 9: overview.Rnw:569-570
 ###################################################
 om <- omega(Thurstone,n.obs=213)
 
 
 ###################################################
-### code chunk number 33: overview.Rnw:970-972
+### code chunk number 10: overview.Rnw:603-605
 ###################################################
 data(bfi)
 ic <- iclust(bfi[1:25])
 
 
 ###################################################
-### code chunk number 34: overview.Rnw:984-985
+### code chunk number 11: overview.Rnw:617-618
 ###################################################
 summary(ic)  #show the results
 
 
 ###################################################
-### code chunk number 35: overview.Rnw:998-1000
+### code chunk number 12: overview.Rnw:631-633
 ###################################################
 data(bfi)
 r.poly <- polychoric(bfi[1:25]) #the ... indicate the progress of the function
 
 
 ###################################################
-### code chunk number 36: overview.Rnw:1013-1015
+### code chunk number 13: overview.Rnw:646-648
 ###################################################
 ic.poly <- iclust(r.poly$rho,title="ICLUST using polychoric correlations")
 iclust.diagram(ic.poly) 
 
 
 ###################################################
-### code chunk number 37: overview.Rnw:1026-1028
+### code chunk number 14: overview.Rnw:659-661
 ###################################################
 ic.poly <- iclust(r.poly$rho,5,title="ICLUST using polychoric correlations for nclusters=5")
 iclust.diagram(ic.poly) 
 
 
 ###################################################
-### code chunk number 38: overview.Rnw:1039-1040
+### code chunk number 15: overview.Rnw:672-673
 ###################################################
 ic.poly <- iclust(r.poly$rho,beta.size=3,title="ICLUST beta.size=3")
 
 
 ###################################################
-### code chunk number 39: overview.Rnw:1052-1053
+### code chunk number 16: overview.Rnw:685-686
 ###################################################
 print(ic,cut=.3)
 
 
 ###################################################
-### code chunk number 40: overview.Rnw:1072-1074
+### code chunk number 17: overview.Rnw:705-707
 ###################################################
 fa(bfi[1:10],2,n.iter=20)
 
 
 
 ###################################################
-### code chunk number 41: overview.Rnw:1087-1089
+### code chunk number 18: overview.Rnw:720-722
 ###################################################
 f4 <- fa(bfi[1:25],4,fm="pa")
 factor.congruence(f4,ic)
 
 
 ###################################################
-### code chunk number 42: overview.Rnw:1098-1099
+### code chunk number 19: overview.Rnw:731-732
 ###################################################
 factor.congruence(list(f3t,f3o,om,p3p))
 
 
 ###################################################
-### code chunk number 43: overview.Rnw:1143-1144
+### code chunk number 20: overview.Rnw:776-777
 ###################################################
 vss <- vss(bfi[1:25],title="Very Simple Structure of a Big 5 inventory")
 
 
 ###################################################
-### code chunk number 44: overview.Rnw:1152-1153
+### code chunk number 21: overview.Rnw:785-786
 ###################################################
 vss
 
 
 ###################################################
-### code chunk number 45: overview.Rnw:1163-1164
+### code chunk number 22: overview.Rnw:796-797
 ###################################################
 fa.parallel(bfi[1:25],main="Parallel Analysis of a Big 5 inventory")
 
 
 ###################################################
-### code chunk number 46: overview.Rnw:1182-1187
+### code chunk number 23: overview.Rnw:815-820
 ###################################################
 v16 <- sim.item(16)
 s <- c(1,3,5,7,9,11,13,15)
@@ -325,7 +157,7 @@ fa.diagram(f2,fe=fe)
 
 
 ###################################################
-### code chunk number 47: overview.Rnw:1203-1210
+### code chunk number 24: overview.Rnw:836-843
 ###################################################
 fx <-matrix(c( .9,.8,.6,rep(0,4),.6,.8,-.7),ncol=2)  
 fy <- matrix(c(.6,.5,.4),ncol=1)
@@ -337,20 +169,20 @@ print(gre.gpa)
 
 
 ###################################################
-### code chunk number 48: overview.Rnw:1216-1218
+### code chunk number 25: overview.Rnw:849-851
 ###################################################
 esem.example <- esem(gre.gpa$model,varsX=1:5,varsY=6:8,nfX=2,nfY=1,n.obs=1000,plot=FALSE)
 esem.example
 
 
 ###################################################
-### code chunk number 49: overview.Rnw:1223-1224
+### code chunk number 26: overview.Rnw:856-857
 ###################################################
  esem.diagram(esem.example)
 
 
 ###################################################
-### code chunk number 50: overview.Rnw:1276-1280
+### code chunk number 27: overview.Rnw:909-913
 ###################################################
 set.seed(17)
 r9 <- sim.hierarchical(n=500,raw=TRUE)$observed
@@ -359,7 +191,7 @@ alpha(r9)
 
 
 ###################################################
-### code chunk number 51: overview.Rnw:1287-1290
+### code chunk number 28: overview.Rnw:920-923
 ###################################################
 
 alpha(attitude,keys=c("complaints","critical"))
@@ -367,45 +199,45 @@ alpha(attitude,keys=c("complaints","critical"))
 
 
 ###################################################
-### code chunk number 52: overview.Rnw:1297-1299
+### code chunk number 29: overview.Rnw:930-932
 ###################################################
 
 alpha(attitude)
 
 
 ###################################################
-### code chunk number 53: overview.Rnw:1306-1308
+### code chunk number 30: overview.Rnw:939-941
 ###################################################
 items <- sim.congeneric(N=500,short=FALSE,low=-2,high=2,categorical=TRUE) #500 responses to 4 discrete items
 alpha(items$observed)  #item response analysis of congeneric measures
 
 
 ###################################################
-### code chunk number 54: overview.Rnw:1361-1362
+### code chunk number 31: overview.Rnw:994-995
 ###################################################
 om.9 <- omega(r9,title="9 simulated variables")
 
 
 ###################################################
-### code chunk number 55: overview.Rnw:1373-1374
+### code chunk number 32: overview.Rnw:1006-1007
 ###################################################
 om.9
 
 
 ###################################################
-### code chunk number 56: overview.Rnw:1382-1383
+### code chunk number 33: overview.Rnw:1015-1016
 ###################################################
 omegaSem(r9,n.obs=500,lavaan=FALSE)
 
 
 ###################################################
-### code chunk number 57: overview.Rnw:1392-1393
+### code chunk number 34: overview.Rnw:1025-1026
 ###################################################
 splitHalf(r9)
 
 
 ###################################################
-### code chunk number 58: overview.Rnw:1407-1427
+### code chunk number 35: overview.Rnw:1040-1060
 ###################################################
  #the newer way is probably preferred 
      
@@ -422,7 +254,7 @@ keys.list  <- list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10),
  Openness = c(21,-22,23,24,-25))
           
 #These two approaches can be mixed if desired
- keys.list <- list(agree=c("-A1","A2","A3","A4","A5"),conscientious=c("C1","C2","C2","-C4","-C5"),
+ keys.list <- list(agree=c("-A1","A2","A3","A4","A5"),conscientious=c("C1","C2","C3","-C4","-C5"),
            extraversion=c("-E1","-E2","E3","E4","E5"),
             neuroticism=c(16:20),openness = c(21,-22,23,24,-25)) 
 
@@ -430,14 +262,14 @@ keys.list  <- list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10),
 
 
 ###################################################
-### code chunk number 59: overview.Rnw:1449-1451
+### code chunk number 36: overview.Rnw:1082-1084
 ###################################################
  scores <- scoreItems(keys.list,bfi)
  scores
 
 
 ###################################################
-### code chunk number 60: scores
+### code chunk number 37: scores
 ###################################################
 png('scores.png')
 pairs.panels(scores$scores,pch='.',jiggle=TRUE)
@@ -445,7 +277,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 61: overview.Rnw:1477-1480
+### code chunk number 38: overview.Rnw:1110-1113
 ###################################################
 r.bfi <- cor(bfi,use="pairwise")
 scales <- scoreItems(keys.list,r.bfi)
@@ -453,7 +285,7 @@ summary(scales)
 
 
 ###################################################
-### code chunk number 62: overview.Rnw:1490-1496
+### code chunk number 39: overview.Rnw:1123-1129
 ###################################################
 data(iqitems)
 iq.keys <- c(4,4,4, 6,6,3,4,4,  5,2,2,4,  3,2,6,7)
@@ -464,7 +296,7 @@ describe(iq.tf)  #compare to previous results
 
 
 ###################################################
-### code chunk number 63: overview.Rnw:1514-1520
+### code chunk number 40: overview.Rnw:1147-1153
 ###################################################
 data(iqitems)
 iq.keys <- c(4,4,4, 6,6,3,4,4,  5,2,2,4,  3,2,6,7)
@@ -475,21 +307,21 @@ irt.responses(scores$scores,iqitems[1:4],breaks=11)
 
 
 ###################################################
-### code chunk number 64: overview.Rnw:1532-1534
+### code chunk number 41: overview.Rnw:1165-1167
 ###################################################
  m <- colMeans(bfi,na.rm=TRUE)
   item.lookup(scales$item.corrected[,1:3],m,dictionary=bfi.dictionary[1:2])
 
 
 ###################################################
-### code chunk number 65: overview.Rnw:1542-1544
+### code chunk number 42: overview.Rnw:1175-1177
 ###################################################
 data(bfi)
 bestScales(bfi,criteria=c("gender","education","age"),cut=.1,dictionary=bfi.dictionary[,1:3])
 
 
 ###################################################
-### code chunk number 66: overview.Rnw:1568-1572
+### code chunk number 43: overview.Rnw:1201-1205
 ###################################################
 set.seed(17)
 d9 <- sim.irt(9,1000,-2.5,2.5,mod="normal") #dichotomous items
@@ -498,7 +330,7 @@ test
 
 
 ###################################################
-### code chunk number 67: overview.Rnw:1579-1584
+### code chunk number 44: overview.Rnw:1212-1217
 ###################################################
 op <- par(mfrow=c(3,1))
 plot(test,type="ICC")
@@ -508,7 +340,7 @@ op <- par(mfrow=c(1,1))
 
 
 ###################################################
-### code chunk number 68: overview.Rnw:1595-1598
+### code chunk number 45: overview.Rnw:1228-1231
 ###################################################
 data(bfi)
 e.irt <- irt.fa(bfi[11:15])
@@ -516,43 +348,43 @@ e.irt
 
 
 ###################################################
-### code chunk number 69: overview.Rnw:1605-1606
+### code chunk number 46: overview.Rnw:1238-1239
 ###################################################
 e.info  <- plot(e.irt,type="IIC")
 
 
 ###################################################
-### code chunk number 70: overview.Rnw:1617-1618
+### code chunk number 47: overview.Rnw:1250-1251
 ###################################################
 print(e.info,sort=TRUE)
 
 
 ###################################################
-### code chunk number 71: overview.Rnw:1647-1648
+### code chunk number 48: overview.Rnw:1280-1281
 ###################################################
 iq.irt <- irt.fa(ability)
 
 
 ###################################################
-### code chunk number 72: overview.Rnw:1660-1661
+### code chunk number 49: overview.Rnw:1293-1294
 ###################################################
 plot(iq.irt,type='test') 
 
 
 ###################################################
-### code chunk number 73: overview.Rnw:1672-1673
+### code chunk number 50: overview.Rnw:1305-1306
 ###################################################
 iq.irt 
 
 
 ###################################################
-### code chunk number 74: overview.Rnw:1679-1680
+### code chunk number 51: overview.Rnw:1312-1313
 ###################################################
 om <- omega(iq.irt$rho,4)
 
 
 ###################################################
-### code chunk number 75: overview.Rnw:1694-1708
+### code chunk number 52: overview.Rnw:1327-1341
 ###################################################
 v9 <- sim.irt(9,1000,-2.,2.,mod="normal") #dichotomous items
 items <- v9$items
@@ -571,14 +403,14 @@ colnames(scores.df) <- c("True theta","irt theta","total","fit","rasch","total",
 
 
 ###################################################
-### code chunk number 76: overview.Rnw:1717-1719
+### code chunk number 53: overview.Rnw:1350-1352
 ###################################################
  pairs.panels(scores.df,pch='.',gap=0)
  title('Comparing true theta for IRT, Rasch and  classically based scoring',line=3)
 
 
 ###################################################
-### code chunk number 77: overview.Rnw:1731-1747
+### code chunk number 54: overview.Rnw:1364-1380
 ###################################################
 keys.list  <- list(agree=c("-A1","A2","A3","A4","A5"),
       conscientious=c("C1","C2","C3","-C4","-C5"),
@@ -599,7 +431,7 @@ bfi.ctt <- scoreFast(keys.list,bfi) # fast scoring function
 
 
 ###################################################
-### code chunk number 78: overview.Rnw:1752-1756
+### code chunk number 55: overview.Rnw:1385-1389
 ###################################################
 #compare the solutions using the cor2 function
  cor2(bfi.1pl,bfi.ctt)
@@ -608,7 +440,7 @@ cor2(bfi.2pl,bfi.ctt)
 
 
 ###################################################
-### code chunk number 79: overview.Rnw:1820-1824
+### code chunk number 56: overview.Rnw:1453-1457
 ###################################################
 
 C <- cov(sat.act,use="pairwise")
@@ -617,14 +449,14 @@ summary(model1)
 
 
 ###################################################
-### code chunk number 80: overview.Rnw:1827-1829
+### code chunk number 57: overview.Rnw:1460-1462
 ###################################################
 #compare with sector
 setCor(c(4:6),c(1:3),C, n.obs=700)
 
 
 ###################################################
-### code chunk number 81: overview.Rnw:1912-1936
+### code chunk number 58: overview.Rnw:1545-1569
 ###################################################
 xlim=c(0,10)
 ylim=c(0,10)
@@ -653,7 +485,7 @@ dia.curved.arrow(mr,lr$top)
 
 
 ###################################################
-### code chunk number 82: overview.Rnw:2048-2049
+### code chunk number 59: overview.Rnw:1681-1682
 ###################################################
 sessionInfo()
 
